<p align="center">
  <!-- <img width="300" src="" alt="Cover image"> -->
  <h1 align="center" style="margin: 0 auto 0 auto;">Flask-authgen-jwt</h1>
  <h5 align="center" style="margin: 0 auto 0 auto;">A flask library to generate JWT and authenticate using JWT</h5>
</p>

<p align="center">
  <img alt="Last commit" src="https://img.shields.io/github/last-commit/dmtzs/Flask-authgen-jwt?logo=Conventional Commits">
  <img alt="Contributors" src="https://img.shields.io/github/contributors/dmtzs/Flask-authgen-jwt?logo=Handshake">
  <img alt="Issues" src="https://img.shields.io/github/issues/dmtzs/Flask-authgen-jwt?label=issues&logo=Eclipse Mosquitto">
  <img alt="Stars" src="https://img.shields.io/github/stars/dmtzs/Flask-authgen-jwt">
  <img alt="GitHub top language" src="https://img.shields.io/github/languages/top/dmtzs/Flask-authgen-jwt?logo=python">
</p>

<p align="center">
  <img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/dmtzs/Flask-authgen-jwt">
  <img alt="Code size" src="https://img.shields.io/github/languages/code-size/dmtzs/Flask-authgen-jwt">
  <img alt="GitHub language count" src="https://img.shields.io/github/languages/count/dmtzs/Flask-authgen-jwt">
  <img alt="Pylint github action" src="https://github.com/dmtzs/Flask-authgen-jwt/actions/workflows/pylint.yml/badge.svg">
  <img alt="Pypi github action" src="https://github.com/dmtzs/Flask-authgen-jwt/actions/workflows/python-publish.yml/badge.svg">
</p>

- [Documentation](#Documentation)
- [Supported versions for releases](#Supported-versions-for-releases)


## Documentation
You can go to the documentation going to the wiki of this repository or click [here](https://github.com/dmtzs/Flask-authgen-jwt/wiki) to go to the wiki directly

## Supported versions for releases
Here you can see a description of the versions supported or that are deprecated but still functional.
Please click [here](https://github.com/dmtzs/Flask-authgen-jwt/blob/master/SECURITY.md) to go that specification.